@@ -43,7 +43,6 @@ mlp = {
     'hidden_layer_sizes':[(25,),(25,25,)],
     'solver':['lbfgs','adam'],
     'normalizer':['minmax','scale'],
-    'random_state':[20],
 }
 
 mlr = {
@@ -131,7 +130,6 @@ mlp = {
     'hidden_layer_sizes':[(25,),(25,25,)],
     'solver':['lbfgs','adam'],
     'normalizer':['minmax','scale'],
-    'random_state':[20],
     'lags':[1,3,6],
 }
 
@@ -196,6 +194,7 @@ xgboost = {}
 
 import os
 
+
 def get_example_grids(overwrite=False):
     """ saves example grids to working directory as Grids.py (does not overwrite by default).
 
@@ -205,13 +204,14 @@ def get_example_grids(overwrite=False):
     Returns:
         None
     """
-    if 'Grids.py' in os.listdir('./'):
+    if "Grids.py" in os.listdir("./"):
         if not overwrite:
             return
-    
-    with open('Grids.py','w') as fl:
+
+    with open("Grids.py", "w") as fl:
         fl.write(example_grids)
 
+
 def get_mv_grids(overwrite=False):
     """ saves example grids to working directory as MVGrids.py (does not overwrite by default).
 
@@ -221,13 +221,14 @@ def get_mv_grids(overwrite=False):
     Returns:
         None
     """
-    if 'MVGrids.py' in os.listdir('./'):
+    if "MVGrids.py" in os.listdir("./"):
         if not overwrite:
             return
-    
-    with open('MVGrids.py','w') as fl:
+
+    with open("MVGrids.py", "w") as fl:
         fl.write(mv_grids)
 
+
 def get_empty_grids(overwrite=False):
     """ saves empty grids to working directory as Grids.py (does not overwrite by default).
 
@@ -237,9 +238,9 @@ def get_empty_grids(overwrite=False):
     Returns:
         None
     """
-    if 'Grids.py' in os.listdir('./'):
+    if "Grids.py" in os.listdir("./"):
         if not overwrite:
             return
-    
-    with open('Grids.py','w') as fl:
-        fl.write(empty_grids)
\ No newline at end of file
+
+    with open("Grids.py", "w") as fl:
+        fl.write(empty_grids)
